{% extends "registration/registration_base.html" %}
{% load i18n %}

{% block title %}{% trans "Account Activated" %}{% endblock %}

{% block content %}
<p>
    {% trans "Your account is now activated." %}
    {% if not user.is_authenticated %}
    {% trans "Once a site administrator activates your account you can login." %}
    {% endif %}
</p>
{% endblock %}


{% comment %}
**registration/activation_complete.html**

Used after successful account activation. This template has no context
variables of its own, and should simply inform the user that their
account is now active.
{% endcomment %}
