{% load i18n %}

{% blocktrans %}Greetings{% endblocktrans %} {% if user.get_full_name %}{{ user.get_full_name }}{% else %}{{ user }}{% endif %},

{% blocktrans %}
You are receiving this email because you (or someone pretending to be you)
requested that your password be reset on the {{ domain }} site. If you do not
wish to reset your password, please ignore this message.
{% endblocktrans %}

{% blocktrans %}
To reset your password, please click the following link, or copy and paste it
into your web browser:
{% endblocktrans %}

<a rel="noreferrer" href="{{ protocol }}://{{ domain }}{% url 'auth_password_reset_confirm' uid token %}">
  {{ protocol }}://{{ domain }}{% url 'auth_password_reset_confirm' uid token %}
</a>

{% blocktrans %}Your username, in case you've forgotten:{% endblocktrans %} {{ user.get_username }}


{% blocktrans %}Best regards{% endblocktrans %},
{{ site_name }} {% blocktrans %}Management{% endblocktrans %}


{# This is used by django.contrib.auth #}
