{% extends "registration/registration_base.html" %}
{% load crispy_forms_tags %}
{% load i18n %}

{% block title %}{% trans "Activation email sent" %}{% endblock %}

{% block content %}
<p>{% trans "Please check your email to complete the registration process." %}</p>
{% endblock %}


{% comment %}
**registration/registration_complete.html**

Used after successful completion of the registration form. This
template has no context variables of its own, and should simply inform
the user that an email containing account-activation information has
been sent.
{% endcomment %}
