{% extends "registration/registration_base.html" %}
{% load crispy_forms_tags %}
{% load i18n %}

{% block meta %}
<!-- NOTE(joshblum): This prevents leaking the password reset token via the
   Referer header to any 3rd party apps on the page. -->
<meta name="referrer" content="origin">
{% endblock %}

{% block title %}{% trans "Confirm password reset" %}{% endblock %}

{% block content %}
{% if validlink %}
  <p>{% trans "Enter your new password below to reset your password:" %}</p>
  <form method="post" action="" class="row g-3 needs-validation" novalidate>
      {% csrf_token %}
      {{ form|crispy }}
      <input type="submit" class="btn btn-sm btn-outline-primary" value="{% trans 'Set password' %}" />
  </form>
{% else %}
  Password reset unsuccessful. Please <a href="{% url 'auth_password_reset' %}">try again.</a>
{% endif %}
{% endblock %}


{# This is used by django.contrib.auth #}
